@@ -612,10 +612,13 @@ static PyObject* Fprofile_ThreadFunctionTrace(PyObject* obj, PyFrameObject* fram
     int what, PyObject* arg) {
     Fprofile_CreateThreadState();
 
-    // Replace our setprofile() handler with the real one, then manually call
-    // it to ensure this call is recorded.
+    // Replace our setprofile() handler with the real one.
     PyEval_SetProfile(Fprofile_FunctionTrace, NULL);
-    Fprofile_FunctionTrace(obj, frame, what, arg);
+
+    // We previously called `Fprofile_FunctionTrace` to manually recorded this
+    // call, but that's both not very interesting as well as causes crashes on
+    // startup for some Python versions (due to insufficiently initialized
+    // frames), so we don't do that anymore.
     Py_RETURN_NONE;
 }
 
