@@ -40,7 +40,7 @@ def setup_dependencies():
 
     # Generate wrappers for the various Python versions we support to ensure
     # they're included in our PATH.
-    wrap_pythons = ["python", "python3", "python3.6", "python3.7", "python3.8"]
+    wrap_pythons = ["python", "python3"] + ["python3.{}".format(minor) for minor in range(6, 12)]
     for python in wrap_pythons:
         with open(os.path.join(tempdir, python), "w") as f:
             f.write(PYTHON_TEMPLATE.format(python=python))
